@@ -6,7 +6,7 @@ class SimConsts:
     DEFAULT_CONDITION = ""
     COMBO_SUCCESS = ""
     COMBO_FAIL = "No Combo"
-    DEFAULT_TARGET = "__Default Target"
+    DEFAULT_TARGET = "Default Target"
     LB_MEAN_DAMAGE = "Mean Damage:"
     LB_EXACT_DAMAGE = "Exact Damage:"
   
\ No newline at end of file
